@@ -110,7 +110,11 @@ def get_sourceColor(source=None):
         "Nitrate rich": "#217ecb", # "#ff7f2a",
         "Secondary_inorganics": "#0000cc",
         "MSA_rich": "#ff7f2a", # 8c564b",
+        "MSA-rich": "#ff7f2a", # 8c564b",
         "Secondary_oxidation": "#ff87dc",
+        "Secondary_biogenic_oxidation": "#ff87dc",
+        "Secondary oxidation": "#ff87dc",
+        "Secondary biogenic oxidation": "#ff87dc",
         "Marine SOA": "#ff7f2a", # 8c564b",
         "Biogenic SOA": "#8c564b",
         "Anthropogenic SOA": "#8c564b",
@@ -213,10 +217,12 @@ def get_sourcesCategories(profiles):
         "Secondary biogenic": "MSA_rich",
         "Secondary organic": "MSA_rich",
         "Secondary oxidation": "Secondary_oxidation",
+        "Secondary biogenic oxidation": "Secondary_biogenic_oxidation",
         "Secondaire organique": "MSA_rich",
         # "Marine SOA": "Marine SOA",
         "Marine SOA": "MSA_rich",
         "MSA_rich": "MSA_rich",
+        "MSA-rich": "MSA-rich",
         "MSA rich": "MSA_rich",
         "Secondary biogenic/sulfate": "SOA/sulfate (Mix)",
         "Marine SOA/SO4": "SOA/sulfate (Mix)",
