@@ -1,11 +1,13 @@
 import pandas as pd
 import matplotlib.pyplot as plt
 import matplotlib.ticker as mticker
+import seaborn as sns
 from py4pm.chemutilities import get_sourceColor, get_sourcesCategories, format_ions
 
 class CachedAccessor:
      """
      Custom property-like object (descriptor) for caching accessors.
+
      Parameters
      ----------
      name : str
@@ -34,6 +36,10 @@ class CachedAccessor:
 
 
 class ReaderAccessor():
+    """
+    Accessor class for the PMF class with all reader methods.
+    """
+
     def __init__(self, data):
         self._parent = data
     
@@ -41,9 +47,10 @@ class ReaderAccessor():
         """Get profiles, species and co
 
         It add a totalVariable (by default one of "PM10", "PM2.5", "PMrecons" or
-        "PM10recons", "PM10rec"]. Otherwise, try to guess.
-
+        "PM10recons", "PM10rec"). Otherwise, try to guess (variable with "PM" on its
+        name).
         """
+
         pmf = self._parent
         if pmf.dfprofiles_b is None:
             pmf.read.read_base_profiles()
@@ -66,12 +73,38 @@ class ReaderAccessor():
             pmf.totalVar = pmf.totalVar[0]
         print("Total variable set to: {}".format(pmf.totalVar))
 
-    def read_base_profiles(self):
-        """TODO: Docstring for read_base_profiles.
+    def _split_df_by_nan(self, df):
+        """Internet method the read the bootstrap file format:
+        1 block of N lines (1 per factor) for each species, separated by an empty line.
 
-        Returns
-        -------
-        TODO
+        Parameter
+        ---------
+
+        df : pd.DataFrame
+            The bootstrap data from the xlsx files. The header should be already removed.
+
+        Return
+        ------
+
+        pd.DataFrame, formatted by factor and species
+
+        """
+        pmf = self._parent
+        d = {}
+        dftmp = df.dropna()
+        for i, sp in enumerate(pmf.species):
+            d[sp] = dftmp.iloc[pmf.nprofiles*i:pmf.nprofiles*(i+1), :]
+            d[sp].index = pmf.profiles
+            d[sp].index.name = "profile"
+            d[sp].columns = ["Boot{}".format(i) for i in range(len(d[sp].columns))]
+        return d
+
+
+    def read_base_profiles(self):
+        """Read the "base" profiles result from the file: '_base.xlsx',
+        sheet "Profiles", and add :
+
+        - self.dfprofiles_b: constrained factors profile
 
         """
         pmf = self._parent
@@ -107,9 +140,10 @@ class ReaderAccessor():
         pmf.read.read_metadata()
 
     def read_constrained_profiles(self):
-        """TODO: Docstring for read_constrained_profiles.
+        """Read the "constrained" profiles result from the file: '_Constrained.xlsx',
+        sheet "Profiles", and add :
 
-        :returns: TODO
+        - self.dfprofiles_c: constrained factors profile
 
         """
         pmf = self._parent
@@ -149,9 +183,10 @@ class ReaderAccessor():
         pmf.dfprofiles_c = dfcons
 
     def read_base_contributions(self):
-        """TODO: Docstring for read_base_contributions.
+        """Read the "base" contributions result from the file: '_base.xlsx',
+        sheet "Contributions", and add :
 
-        :returns: TODO
+        - self.dfcontrib_b: base factors contribution
 
         """
         pmf = self._parent
@@ -162,7 +197,7 @@ class ReaderAccessor():
         dfcontrib = pd.read_excel(
             pmf._basename+"_base.xlsx",
             sheet_name=['Contributions'],
-            parse_date=["date"],
+            parse_dates=["date"],
             header=None,
         )["Contributions"]
 
@@ -188,9 +223,10 @@ class ReaderAccessor():
         pmf.dfcontrib_b = dfcontrib
 
     def read_constrained_contributions(self):
-        """TODO: Docstring for read_constrained_contributions.
+        """Read the "constrained" contributions result from the file: '_Constrained.xlsx',
+        sheet "Contributions", and add :
 
-        :returns: TODO
+        - self.dfcontrib_c: constrained factors contribution
 
         """
         pmf = self._parent
@@ -201,7 +237,7 @@ class ReaderAccessor():
         dfcontrib = pd.read_excel(
             pmf._basename+"_Constrained.xlsx",
             sheet_name=['Contributions'],
-            parse_date=["date"],
+            parse_dates=["date"],
             header=None,
         )["Contributions"]
 
@@ -226,9 +262,11 @@ class ReaderAccessor():
         pmf.dfcontrib_c = dfcontrib.infer_objects()
 
     def read_base_bootstrap(self):
-        """TODO: Docstring for read_base_bootstrap.
+        """Read the "base" bootstrap result from the file: '_boot.xlsx'
+        and add :
 
-        :returns: TODO
+        - self.dfBS_profile_b: all mapped profile
+        - self.dfbootstrap_mapping_b: table of mapped profiles
 
         """
         pmf = self._parent
@@ -252,7 +290,7 @@ class ReaderAccessor():
 
         # 13 is the first column for BS result
         dfprofile_boot = dfprofile_boot.iloc[idx[0]+1:, 13:]
-        df = pmf._split_df_by_nan(dfprofile_boot)
+        df = self._split_df_by_nan(dfprofile_boot)
 
         df = pd.concat(df)
         df.index.names = ["specie", "profile"]
@@ -281,11 +319,12 @@ class ReaderAccessor():
         pmf.dfbootstrap_mapping_b = dfbootstrap_mapping_b
 
     def read_constrained_bootstrap(self):
-        """Read the '_Gcon_profile_boot.xlsx' and format it in dataframe
+        """Read the "base" bootstrap result from the file: '_Gcon_profile_boot.xlsx'
+        and add :
 
-        Add:
         - self.dfBS_profile_c: all mapped profile
         - self.dfbootstrap_mapping_c: table of mapped profiles
+
         """
         pmf = self._parent
 
@@ -307,7 +346,7 @@ class ReaderAccessor():
         idx = idx[idx].index.tolist()
         # 13 is the first column for BS result
         dfprofile_boot = dfprofile_boot.iloc[idx[0]+1:, 13:]
-        df = pmf._split_df_by_nan(dfprofile_boot)
+        df = self._split_df_by_nan(dfprofile_boot)
 
         df = pd.concat(df)
         df.index.names = ["specie", "profile"]
@@ -335,7 +374,9 @@ class ReaderAccessor():
         pmf.dfbootstrap_mapping_c = dfbootstrap_mapping_c
 
     def read_base_uncertainties_summary(self):
-        """Read the _BaseErrorEstimationSummary.xlsx file
+        """Read the _BaseErrorEstimationSummary.xlsx file and add:
+
+        - self.df_uncertainties_summary_b : uncertainties from BS, DISP and BS-DISP
 
         """
         pmf = self._parent
@@ -394,7 +435,9 @@ class ReaderAccessor():
         pmf.df_uncertainties_summary_b = df.infer_objects()
 
     def read_constrained_uncertainties_summary(self):
-        """Read the _ConstrainedErrorEstimationSummary.xlsx file
+        """Read the _ConstrainedErrorEstimationSummary.xlsx file and add :
+
+        - self.df_uncertainties_summary_b : uncertainties from BS, DISP and BS-DISP
 
         """
         pmf = self._parent
@@ -453,6 +496,9 @@ class ReaderAccessor():
 
 
 class PlotterAccessor():
+    """
+    Accessor class for the PMF class with all plotter methods.
+    """
     def __init__(self, data):
         self._parent = data
 
@@ -463,19 +509,21 @@ class PlotterAccessor():
     def _save_plot(self, formats=["png"], name="plot", DIR=""):
         """Save plot in a given format.
         
-        :formats: list, format of the figure (see plt.savefig)
-        :name: string, default "plot". File name.
-        :DIR: string, default "". Directory.
+        Parameters
+        ----------
+
+        formats : list of str, format of the figure (see plt.savefig)
+        name : string, default "plot". File name.
+        DIR : string, default "". Directory for saving.
         """
         for fmt in formats:
             plt.savefig("{DIR}{name}.{fmt}".format(DIR=DIR,
                                                    name=name.replace("/", "-"), fmt=fmt))
 
-    def _plot_per_microgramm(self, constrained=True, df=None, profile=None, species=None,
+    def _plot_per_microgramm(self, df=None, constrained=True, profile=None, species=None,
                              new_figure=False, **kwargs):
+        """Internal method
         """
-        """
-        import seaborn as sns
         pmf = self._parent
 
         if new_figure:
@@ -515,19 +563,20 @@ class PlotterAccessor():
         labels = ["Ref. run", "BS"]
         ax.legend(handles=handles, labels=labels, loc="upper left", bbox_to_anchor=(1., 1.), frameon=False)
 
-    def _plot_totalspeciesum(self, constrained=True, df=None, profile=None,
+    def _plot_totalspeciesum(self, df=None, constrained=True, profile=None,
                              species=None, sumsp=None, new_figure=False,
                              **kwargs):
-        import seaborn as sns
         """TODO: Docstring for _plot_totalspeciesum.
 
-        :df: TODO
-        :constrained: Boolean, either to use the constrained run or the base run
-        :profile: TODO
-        :species: TODO
-        :sumsp: dataframe with the sum of each species
-        :new_figure: TODO
-        :returns: TODO
+        Parameters
+        ----------
+
+        df : TODO
+        constrained : Boolean, either to use the constrained run or the base run
+        profile : TODO
+        species : TODO
+        sumsp : dataframe with the sum of each species
+        new_figure : TODO
 
         """
         pmf = self._parent
@@ -549,10 +598,11 @@ class PlotterAccessor():
                 sumsp[sp] = df.loc[(sp, slice(None)), :].mean(axis=1).sum()
 
         d = df.xs(profile, level="profile").divide(sumsp.iloc[0], axis=0) * 100
+        d.index.names = ["specie"]
         d = d.reindex(species).unstack().reset_index()
         dref = dfprofiles[profile].divide(dfprofiles.sum(axis=1)) * 100
         dref = dref.reset_index()
-        sns.barplot(data=d, x="level_1", y=0, color="grey", ci="sd", ax=ax,
+        sns.barplot(data=d, x="specie", y=0, color="grey", ci="sd", ax=ax,
                     label="BS (sd)")
         sns.stripplot(data=dref, x="specie", y=0, color="red", jitter=False,
                       ax=ax, label="Ref. run")
@@ -578,19 +628,17 @@ class PlotterAccessor():
         Parameters
         ----------
 
-        dfBS : pd.DataFrame
-        dfDISP: TODO
-        :dfcontrib: TODO
-        :profile: TODO
-        :specie: TODO
-        :BS: TODO
-        :DISP: TODO
-        :BSDISP: TODO
-        :new_figure: TODO
-        :returns: TODO
+        dfBS  : pd.DataFrame
+        dfDISP : TODO
+        dfcontrib : TODO
+        profile : TODO
+        specie : TODO
+        BS : TODO
+        DISP : TODO
+        BSDISP : TODO
+        new_figure : TODO
 
         """
-        import seaborn as sns
         pmf = self._parent
         
         if new_figure:
@@ -648,15 +696,13 @@ class PlotterAccessor():
                       specie=None, BS=False, DISP=False, BSDISP=False):
         """TODO: Docstring for _plot_profile.
 
-        :constrained: Boolean, either to use the constrained run or the base one
-        :dfcontrib: TODO
-        :dfprofile: TODO
-        :profile: TODO
-        :specie: TODO
-        :BS: TODO
-        :DISP: TODO
-        :BSDISP: TODO
-        :returns: TODO
+        constrained : Boolean, either to use the constrained run or the base one
+        dfcontrib : TODO
+        profile : TODO
+        specie : TODO
+        BS : TODO
+        DISP : TODO
+        BSDISP : TODO
 
         """
         pmf = self._parent
@@ -698,16 +744,19 @@ class PlotterAccessor():
         )
 
     def plot_per_microgramm(self, df=None, constrained=True, profiles=None, species=None,
-            plot_save=False, BDIR=None):
+                            plot_save=False, savedir=None):
         """Plot profiles in concentration unique (µg/m3).
 
-        :df: DataFrame with multiindex [species, profile] and an arbitrary
-            number of column.  Default to dfBS_profile_c.
-        :constrained: Boolean, either to use the constrained run or the base run
-        :profiles: list, profile to plot (one figure per profile)
-        :species: list, specie to plot (x-axis)
-        :plot_save: boolean, default False. Save the graph in BDIR.
-        :BDIR: string, directory to save the plot.
+        Parameters
+        ----------
+
+        df : DataFrame with multiindex [species, profile] and an arbitrary
+           number of column.  Default to dfBS_profile_c.
+        constrained : Boolean, either to use the constrained run or the base run
+        profiles : list of str, profile to plot (one figure per profile)
+        species : list of str, specie to plot (x-axis)
+        plot_save : boolean, default False. Save the graph in savedir.
+        savedir : string, directory to save the plot.
         """
         pmf = self._parent
 
@@ -742,26 +791,28 @@ class PlotterAccessor():
         elif not(isinstance(species, list)):
             raise TypeError("species should be a list.")
 
-        if BDIR is None:
-            BDIR = pmf._BDIR
+        if savedir is None:
+            savedir = pmf._BDIR
 
         for p in profiles:
-            self._plot_per_microgramm(df, constrained=constrained, profile=p, species=species,
+            self._plot_per_microgramm(df=df, constrained=constrained, profile=p, species=species,
                                       new_figure=True)
             plt.subplots_adjust(left=0.1, right=0.9, bottom=0.3, top=0.9)
-            if plot_save: self._save_plot(DIR=BDIR, name=p+"_profile_perµg")
+            if plot_save: self._save_plot(DIR=savedir, name=p+"_profile_perµg")
 
-    def plot_totalspeciesum(self, df=None, profiles=None, species=None,
-                            constrained=True,
-                            plot_save=False, BDIR=None, **kwargs):
+    def plot_totalspeciesum(self, df=None, profiles=None, species=None, constrained=True,
+                            plot_save=False, savedir=None, **kwargs):
         """Plot profiles in percentage of total specie sum (%).
 
-        :df: DataFrame with multiindex [species, profile] and an arbitrary
-            number of column.  Default to dfBS_profile_c.
-        :profiles: list, profile to plot (one figure per profile)
-        :species: list, specie to plot (x-axis)
-        :plot_save: boolean, default False. Save the graph in BDIR.
-        :BDIR: string, directory to save the plot.
+        Parameters
+        ----------
+
+        df : DataFrame with multiindex [species, profile] and an arbitrary
+           number of column.  Default to dfBS_profile_c.
+        profiles : list, profile to plot (one figure per profile)
+        species : list, specie to plot (x-axis)
+        plot_save : boolean, default False. Save the graph in savedir.
+        savedir : string, directory to save the plot.
         """
         pmf = self._parent
 
@@ -789,26 +840,25 @@ class PlotterAccessor():
                 pmf.read.read_metadata()
             species = pmf.species
 
-        if BDIR is None:
-            BDIR = pmf._BDIR
+        if savedir is None:
+            savedir = pmf._BDIR
 
-        new_figure = kwargs.pop("new_figure", False)
+        new_figure = kwargs.pop("new_figure", True)
 
         sumsp = pd.DataFrame(columns=species, index=['sum'])
         for sp in species:
             sumsp[sp] = df.loc[(sp, slice(None)),:].mean(axis=1).sum()
         for p in profiles:
-            self._plot_totalspeciesum(df, profile=p, species=species,
+            self._plot_totalspeciesum(df=df, profile=p, species=species,
                                       sumsp=sumsp, new_figure=new_figure,
                                       **kwargs)
             plt.subplots_adjust(left=0.1, right=0.9, bottom=0.3, top=0.9)
             if plot_save:
-                self._save_plot(DIR=BDIR, name=p+"_profile")
+                self._save_plot(DIR=savedir, name=p+"_profile")
 
-    def plot_contrib(self, dfBS=None, dfDISP=None, dfcontrib=None, profiles=None, specie=None,
-                     constrained=True,
-                     plot_save=False, BDIR=None, BS=True, DISP=True, BSDISP=False,
-                     new_figure=True, **kwargs):
+    def plot_contrib(self, dfBS=None, dfDISP=None, dfcontrib=None, profiles=None,
+                     specie=None, constrained=True, plot_save=False, savedir=None,
+                     BS=True, DISP=True, BSDISP=False, new_figure=True, **kwargs):
         """Plot temporal contribution in µg/m3.
 
         Parameters
@@ -824,8 +874,8 @@ class PlotterAccessor():
         specie : string, default totalVar.
             specie to plot (y-axis)
         plot_save : boolean, default False
-            Save the graph in BDIR.
-        BDIR : string
+            Save the graph in savedir.
+        savedir : string
             directory to save the plot
         """
         pmf = self._parent
@@ -877,8 +927,8 @@ class PlotterAccessor():
                 "`specie` should be a string, got {}.".format(specie)
             )
 
-        if BDIR is None:
-            BDIR = pmf._BDIR
+        if savedir is None:
+            savedir = pmf._BDIR
 
         for p in profiles:
             self._plot_contrib(dfBS=dfBS, dfDISP=dfDISP,
@@ -888,7 +938,7 @@ class PlotterAccessor():
                                **kwargs)
             plt.subplots_adjust(left=0.1, right=0.85, bottom=0.1, top=0.9)
             if plot_save:
-                self._save_plot(DIR=BDIR, name=p+"_contribution")
+                self._save_plot(DIR=savedir, name=p+"_contribution")
 
     def plot_all_profiles(self, constrained=True, profiles=None, specie=None,
                           BS=True, DISP=True, BSDISP=False, plot_save=False,
@@ -898,7 +948,7 @@ class PlotterAccessor():
         Parameters
         ----------
 
-        constrained: Boolean, default True
+        constrained : Boolean, default True
             Either to use the constrained run or the base one
         profiles : list of string
             Profiles to plot
@@ -980,8 +1030,12 @@ class PlotterAccessor():
     def plot_stacked_contribution(self, constrained=True, order=None, plot_kwargs=None):
         """Plot a stacked plot for the contribution
 
-        :constrained: TODO
-        :returns: TODO
+        Parameters
+        ----------
+
+        constrained : TODO
+        order : TODO
+        plot_kwargs : TODO
 
         """
         pmf = self._parent
@@ -1014,20 +1068,26 @@ class PlotterAccessor():
         )
 
     def plot_seasonal_contribution(self, constrained=True, dfcontrib=None, dfprofiles=None, profiles=None,
-            specie=None, plot_save=False, BDIR=None, annual=True,
+            specie=None, plot_save=False, savedir=None, annual=True,
             normalize=True, ax=None, barplot_kwarg={}):
         """Plot the relative contribution of the profiles.
 
-        :dfcontrib: DataFrame with contribution as column and date as index.
-        :dfprofiles: DataFrame with profile as column and specie as index.
-        :profiles: list, profile to plot (one figure per profile)
-        :specie: string, default totalVar. specie to plot
-        :plot_save: boolean, default False. Save the graph in BDIR.
-        :BDIR: string, directory to save the plot.
-        :annual: plot annual contribution
-        :normalize: plot relative contribution or absolute contribution.
-        
-        :returns: TODO
+        Parameters
+        ----------
+
+        dfcontrib : DataFrame with contribution as column and date as index.
+        dfprofiles : DataFrame with profile as column and specie as index.
+        profiles : list, profile to plot (one figure per profile)
+        specie : string, default totalVar. specie to plot
+        plot_save : boolean, default False. Save the graph in savedir.
+        savedir : string, directory to save the plot.
+        annual : plot annual contribution
+        normalize : plot relative contribution or absolute contribution.
+
+        Return
+        ------
+
+        df : DataFrame
 
         """
         from py4pm.dateutilities import add_season
@@ -1063,8 +1123,8 @@ class PlotterAccessor():
                 pmf.read.read_metadata()
             specie = pmf.totalVar
 
-        if BDIR is None:
-            BDIR = pmf._BDIR
+        if savedir is None:
+            savedir = pmf._BDIR
 
         if ax is None:
             f, ax = plt.subplots(nrows=1, ncols=1, figsize=(7.5, 4.7))
@@ -1100,7 +1160,7 @@ class PlotterAccessor():
             title = "_seasonal_contribution_{}".format(
                     "normalized" if normalize else "absolute"
                     )
-            self._save_plot(DIR=BDIR, name=pmf._site+title)
+            self._save_plot(DIR=savedir, name=pmf._site+title)
         
         return (df)
 
@@ -1155,8 +1215,11 @@ class PMF(object):
     def __init__(self, site, BDIR, program=None):
         """Create a PMF object from the xlsx files output of EPAPMF5.
 
-        :site: str, the name of the site
-        :BDIR: str, the directory where the xlsx files live
+        Parameters
+        ----------
+
+        site : str, the name of the site and prefix of each files
+        BDIR : str, the directory where the xlsx files live
 
         """
         self._site = site
@@ -1191,6 +1254,7 @@ class PMF(object):
 
         Return
         ------
+
         df : dataframe
 
         """
@@ -1218,10 +1282,12 @@ class PMF(object):
         """Compute the factor profile relative mass (i.e. each species divided
         by the totalVar mass)
 
-        :constrained: TODO
-        :species: TODO
-        :profiles: TODO
-        :returns: TODO
+        Parameters
+        ----------
+
+        constrained : TODO
+        species : TODO
+        profiles : TODO
 
         """
         if constrained:
@@ -1266,6 +1332,19 @@ class PMF(object):
                                   normalize=True, constrained=True):
         """
         Get a dataframe of seasonal contribution
+
+        Parameters
+        ----------
+
+        specie :  default None
+        annual : default True
+        normalize : default True
+        constrained : default True
+
+        Return
+        ------
+
+        df : seasonal contribution
         """
         from py4pm.dateutilities import add_season
 
@@ -1337,8 +1416,6 @@ class PMF(object):
 
     def rename_profile_to_profile_category(self):
         """Rename the factor profile name to match the category
-        :returns: TODO
-
         """
         DF = [
             self.dfprofiles_b,
@@ -1363,14 +1440,17 @@ class PMF(object):
         self.profiles = [possible_sources[p] for p in self.profiles]
         
 
-    def recompute_new_species(self, specie=None):
+    def recompute_new_species(self, specie):
         """Recompute a specie given the other species. For instance, recompute OC
         from OC* and a list of organic species.
 
         It modify inplace both dfprofile_b and dfprofile_c, and update
         self.species.
 
-        :specie: str in ["OC",]
+        Parameters
+        ----------
+
+        specie : str in ["OC",]
 
         """
         knownSpecies = ["OC"]
@@ -1418,36 +1498,37 @@ class PMF(object):
             self.dfprofiles_c.loc[specie] = OCc.infer_objects()
 
 
-    def _split_df_by_nan(self, df):
-        """TODO: Docstring for split_df_by_nan.
 
-        :df: TODO
-        :returns: TODO
+    def print_uncertainties_summary(self, constrained=True, profiles=None,
+            species=None):
+        """Get the uncertainties given by BS, BS-DISP and DISP for the given profiles and
+        species
 
+        Parameters
+        ----------
+
+        constrained : boolean, True
+            Use the constrained run (False for the base run)
+        profiles : list of str
+            list of profiles, default all profiles
+        species : list of str
+            list of species, default all species
+
+        Return
+        ------
+
+        df : pd.DataFrame
+            BS, DISP and BS-DISP ranges
         """
-        d = {}
-        dftmp = df.dropna()
-        for i, sp in enumerate(self.species):
-            d[sp] = dftmp.iloc[self.nprofiles*i:self.nprofiles*(i+1), :]
-            d[sp].index = self.profiles
-            d[sp].index.name = "profile"
-            d[sp].columns = ["Boot{}".format(i) for i in range(len(d[sp].columns))]
-        return d
 
-
-    def print_base_uncertainties_summary(self, profiles=None,
-            species=None, BDIR=None):
-        """Print the uncertainties given by BS, BS-DISP and DISP
-        
-        :profiles: list, list of profiles, default all profiles
-        :species: list, list of species, default all species
-        
-        :returns: pd.DataFrame, BS, DISP and BS-DISP ranges
-        """
-        import seaborn as sns
-
-        if self.df_uncertainties_summary_b is None:
-            self.read.read_base_uncertainties_summary()
+        if constrained:
+            if self.df_uncertainties_summary_c is None:
+                self.read.read_constrained_uncertainties_summary()
+            df = self.df_uncertainties_summary_c
+        else:
+            if self.df_uncertainties_summary_b is None:
+                self.read.read_base_uncertainties_summary()
+            df = self.df_uncertainties_summary_b
 
         if profiles is None:
             if self.profiles is None:
@@ -1459,42 +1540,6 @@ class PMF(object):
                 self.read.read_metadata()
             species = self.species
 
-        if BDIR is None:
-            BDIR = self._BDIR
-
-        df = self.df_uncertainties_summary_b
-
-        return df.T.loc[:, (profiles, species)]
-
-    def print_constrained_uncertainties_summary(self, profiles=None,
-            species=None, BDIR=None):
-        """Plot the uncertainties given by BS, BS-DISP and DISP
-        
-        :profiles: list, list of profiles, default all profiles
-        :species: list, list of species, default all species
-        
-        :returns: pd.DataFrame, BS, DISP and BS-DISP ranges
-        """
-        import seaborn as sns
-
-        if self.df_uncertainties_summary_c is None:
-            self.read.read_constrained_uncertainties_summary()
-
-        if profiles is None:
-            if self.profiles is None:
-                self.read.read_metadata()
-            profiles = self.profiles
-
-        if species is None:
-            if self.species is None:
-                self.read.read_metadata()
-            species = self.species
-
-        if BDIR is None:
-            BDIR = self._BDIR
-
-        df = self.df_uncertainties_summary_c
-
         return df.T.loc[:, (profiles, species)]
 
     read = CachedAccessor("read", ReaderAccessor)
